@@ -1,3 +1,3 @@
-`MLE_LambertW` <-
+MLE_LambertW <-
 function(y, distname=c("normal"), theta.0=IGMM(y)$theta) UseMethod("MLE_LambertW")
 
