@@ -1,4 +1,4 @@
-`H` <-
+H <-
 function(u) {
 u*exp(u)
 }
