@@ -1,3 +1,3 @@
-`IGMM` <-
+IGMM <-
 function(y, robust=FALSE, tol=10^(-6), gamma_x = 0) UseMethod("IGMM")
 
