@@ -1,3 +1,3 @@
-`sd` <-
+sd <-
 function(x) sqrt(var(x))
 
